@@ -37,12 +37,15 @@ markdown_extra_tags = [
     'table',
     'tr',
     'th',
-    'th'
+    'th',
+    'thead',
+    'tbody'
 ]
 markdown_extra_attrs = {
     'img': ['src', 'alt'],
     'div': ['class'],
-    'span': ['class']
+    'span': ['class'],
+    'td': ['align']
 }
 
 """
